# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_message_ids_item import AgentsSearchResponseAgentsItemMessageIdsItem

AgentsSearchResponseAgentsItemMessageIds = typing.Union[
    typing.List[str],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMessageIdsItem]],
    typing.Optional[typing.Any],
]
