# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tools_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem,
)

TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem]],
]
