# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Organization(UncheckedBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The human-friendly ID of the Org
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the organization.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The creation date of the organization.
    """

    privileged_tools: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the organization has access to privileged tools.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
