# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem]
    ],
    typing.Optional[typing.Any],
]
